==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QMouseEvent_shell.h <==
#ifndef QMOUSEEVENT_SHELL_H
#define QMOUSEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QMouseEvent_shell : public QMouseEvent, public QtJambiShellInterface
{
public:
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, const QPointF& scenePos2, const QPointF& globalPos3, Qt::MouseButton button4, Qt::MouseButtons buttons5, Qt::KeyboardModifiers modifiers6, Qt::MouseEventSource source7, const QPointingDevice* device8 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, const QPointF& scenePos2, const QPointF& globalPos3, Qt::MouseButton button4, Qt::MouseButtons buttons5, Qt::KeyboardModifiers modifiers6, const QPointingDevice* device7 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, const QPointF& globalPos2, Qt::MouseButton button3, Qt::MouseButtons buttons4, Qt::KeyboardModifiers modifiers5, const QPointingDevice* device6 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, Qt::MouseButton button2, Qt::MouseButtons buttons3, Qt::KeyboardModifiers modifiers4, const QPointingDevice* device5 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(const QMouseEvent& arg__1);
    ~QMouseEvent_shell() override;

    QMouseEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMouseEvent_access : public QMouseEvent
{
    void __qt_assign_cref_QMouseEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMOUSEEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QMouseEvent_shell.h <==
#ifndef QMOUSEEVENT_SHELL_H
#define QMOUSEEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QMouseEvent_shell : public QMouseEvent, public QtJambiShellInterface
{
public:
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, const QPointF& scenePos2, const QPointF& globalPos3, Qt::MouseButton button4, Qt::MouseButtons buttons5, Qt::KeyboardModifiers modifiers6, Qt::MouseEventSource source7, const QPointingDevice* device8 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, const QPointF& scenePos2, const QPointF& globalPos3, Qt::MouseButton button4, Qt::MouseButtons buttons5, Qt::KeyboardModifiers modifiers6, const QPointingDevice* device7 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, const QPointF& globalPos2, Qt::MouseButton button3, Qt::MouseButtons buttons4, Qt::KeyboardModifiers modifiers5, const QPointingDevice* device6 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(QEvent::Type type0, const QPointF& localPos1, Qt::MouseButton button2, Qt::MouseButtons buttons3, Qt::KeyboardModifiers modifiers4, const QPointingDevice* device5 = QPointingDevice::primaryPointingDevice());
    QMouseEvent_shell(const QMouseEvent& arg__1);
    ~QMouseEvent_shell() override;

    QMouseEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMouseEvent_access : public QMouseEvent
{
    void __qt_assign_cref_QMouseEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QMOUSEEVENT_SHELL_H
